@@ -24,7 +24,7 @@ use warnings;
 no warnings;
 use vars qw($VERSION);
 
-$VERSION = '2.11';
+$VERSION = '2.12';
 
 use Carp qw(carp croak);
 use File::Basename qw(dirname);
@@ -1167,7 +1167,7 @@ you may well want to overload it.
 =cut
 
 sub get_changes {
-	open my $fh, '<', 'Changes' or return '';
+	open my $fh, '<:utf8', 'Changes' or return '';
 
 	my $data = <$fh>;  # get first line
 
@@ -1330,7 +1330,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2014 brian d foy.  All rights reserved.
+Copyright © 2002-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
