@@ -2,12 +2,12 @@ package Module::Release::Kwalitee;
 
 use strict;
 use warnings;
-use base qw(Exporter);
+use Exporter qw(import);
 use vars qw($VERSION);
 
 our @EXPORT = qw(check_kwalitee cpants_lint cpants_pass_regex );
 
-$VERSION = '2.11';
+$VERSION = '2.12';
 
 =encoding utf8
 
@@ -92,7 +92,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007-2014, brian d foy, All Rights Reserved.
+Copyright © 2007-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
